SystemOrganization addCategory: 'ConfigurationOfGofer'!

Object subclass: #ConfigurationOfGofer
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfGofer'!

!ConfigurationOfGofer class methodsFor: 'private' stamp: 'DaleHenrichs 1/25/2010 13:14'!
bootstrapPackage: aString from: aPath 
	| repository version |
	repository := MCHttpRepository
				location: aPath
				user: ''
				password: ''.
	repository
		versionReaderForFileNamed: aString , '.mcz'
		do: [:reader | 
			version := reader version.
			version load.
			version workingCopy repositoryGroup addRepository: repository]! !

!ConfigurationOfGofer class methodsFor: 'development support' stamp: 'DaleHenrichs 1/14/2011 11:50'!
compareVersions
	"Compare previous version to development version"

	"self compareVersions"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) compareVersionsIn: self) inspect
! !

!ConfigurationOfGofer class methodsFor: 'development support' stamp: 'DaleHenrichs 1/11/2011 15:01'!
createNewDevelopmentVersion
	"Create a new development version using the #stable version as model."

	"self createNewDevelopmentVersion"
	
	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	(Smalltalk at: #MetacelloToolBox) createNewDevelopmentVersionIn: self description: ''! !

!ConfigurationOfGofer class methodsFor: 'private' stamp: 'DaleHenrichs 1/25/2010 13:14'!
ensureMetacello
	"Bootstrap Gofer (if necessary), bootstrap ConfigurationOfMetacello (using old Gofer API), then load the latest 
	version of Metacello itself."

	Smalltalk at: #MetacelloProject ifAbsent: [
		Smalltalk at: #Gofer ifAbsent: [
			"Current version of Gofer from which to bootstrap - as of 1.0-beta.21"
			self bootstrapPackage: 'Gofer-Core-lr.115' from: 'http://seaside.gemstone.com/ss/metacello' ].
		Smalltalk at: #Gofer ifPresent: [:goferClass | | gofer |
			gofer := goferClass new
				url: 'http://seaside.gemstone.com/ss/metacello';
				yourself.
			[ gofer addPackage: 'ConfigurationOfMetacello' ] on: Warning do: [:ex | ex resume ].
			gofer load ].
		"load 'default' group of Metacello"
		(Smalltalk at: #ConfigurationOfMetacello) perform: #load ]! !

!ConfigurationOfGofer class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 1/25/2010 13:14'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfGofer class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 1/25/2010 13:14'!
lastMetacelloVersionLoad
	"Answer the last version loaded and the list of packages loaded for that version."

	LastVersionLoad == nil ifTrue: [ LastVersionLoad := nil -> 'default' ].
	^LastVersionLoad! !

!ConfigurationOfGofer class methodsFor: 'loading' stamp: 'DaleHenrichs 1/25/2010 13:14'!
load
	"self load"

	^self project latestVersion load! !

!ConfigurationOfGofer class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 1/25/2010 13:14'!
metacelloVersion: versionString loads: anArrayOrString
	"Stash the last version loaded and the list of packages loaded for that version. The list
	 of packages will be used by the tools when doing 'Load Package Version'"

	LastVersionLoad := versionString -> anArrayOrString! !

!ConfigurationOfGofer class methodsFor: 'accessing' stamp: 'DaleHenrichs 1/25/2010 13:14'!
project

	^self new project! !

!ConfigurationOfGofer class methodsFor: 'development support' stamp: 'DaleHenrichs 12/06/2010 11:26'!
updateToLatestPackageVersions: descriptionString
	"Updates mcz file versions in current version"

	"self updateToLatestPackageVersions: '- fixed a bug'"

	"Note: you need 1.0-beta.28 or later for the class MetacelloToolBox"

	self ensureMetacello.
	((Smalltalk at: #MetacelloToolBox) updateToLatestPackageVersionsIn: self description: descriptionString) isEmpty
		ifTrue: [ self inform: 'All specs up to date' ]! !

!ConfigurationOfGofer methodsFor: 'baselines' stamp: 'DaleHenrichs 02/11/2010 10:21'!
baseline100: spec 
	<version: '1.0-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec 
			package: 'Gofer-Core';
			package: 'Gofer-Tests' with: [ spec requires: 'Gofer-Core' ].
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('Gofer-Core');
			group: 'Tests' with: #('Gofer-Tests'). ].
	spec for: #pharo do: [
		spec 
			repository: 'http://www.squeaksource.com/Pharo';
			repository: 'http://seaside.gemstone.com/ss/metacello'. ].
	spec for: #squeak do: [
		spec repository: 'http://seaside.gemstone.com/ss/metacello'. ].
	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/metacello'. ].
! !

!ConfigurationOfGofer methodsFor: 'baselines' stamp: 'DaleHenrichs 6/15/2010 10:47'!
baseline1021: spec 
	<version: '1.0.2.1-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec
			repository: 'http://www.squeaksource.com/metacello';
			repository: 'http://seaside.gemstone.com/ss/metacello'.
		spec 
			package: 'Gofer-Core';
			package: 'Gofer-Tests' with: [ spec requires: 'Gofer-Core' ].
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('Gofer-Core');
			group: 'Tests' with: #('Gofer-Tests'). ].
! !

!ConfigurationOfGofer methodsFor: 'baselines' stamp: 'dkh 06/29/2013 11:50'!
baseline1051: spec
  <version: '1.0.5.1-baseline'>
  spec
    for: #'common'
    do: [ 
      spec blessing: #'baseline'.
      spec
        package: 'Gofer-Core';
        package: 'Gofer-Tests' with: [ spec requires: 'Gofer-Core' ].
      spec
        group: 'default' with: #('Core');
        group: 'Core' with: #('Gofer-Core');
        group: 'Tests' with: #('Gofer-Tests') ].
  spec
    for: #'pharo'
    do: [ spec repository: 'http://www.squeaksource.com/Pharo' ].
  spec
    for: #'pharo1.0.x'
    do: [ 
      spec repository: 'http://seaside.gemstone.com/ss/metacello'.
      spec
        package: 'Gofer-Core' with: 'Gofer-Core.pharo10';
        package: 'Gofer-Tests' with: 'Gofer-Tests.pharo10' ].
  spec
    for: #'pharo1.1.x'
    do: [ 
      spec repository: 'http://seaside.gemstone.com/ss/metacello'.
      spec
        package: 'Gofer-Core' with: 'Gofer-Core.pharo10';
        package: 'Gofer-Tests' with: 'Gofer-Tests.pharo10' ].
  spec
    for: #'squeak'
    do: [ 
      spec
        repository: 'http://smalltalkhub.com/mc/dkh/metacello/main';
        repository: 'http://seaside.gemtalksystems.com/ss/metacello'.
      spec
        package: 'Gofer-Core' with: 'Gofer-Core.squeak';
        package: 'Gofer-Tests' with: 'Gofer-Tests.squeak' ].
  spec
    for: #'gemstone'
    do: [ 
      spec repository: 'http://seaside.gemstone.com/ss/metacello'.
      spec
        package: 'Gofer-Core' with: 'Gofer-Core.gemstone';
        package: 'Gofer-Tests' with: 'Gofer-Tests.gemstone' ]! !

!ConfigurationOfGofer methodsFor: 'baselines' stamp: 'dkh 6/7/2011 15:44'!
baseline105: spec 
	<version: '1.0.5-baseline'>
	
	spec for: #common do: [
		spec blessing: #baseline.
		spec 
			package: 'Gofer-Core';
			package: 'Gofer-Tests' with: [ spec requires: 'Gofer-Core' ].
		spec
			group: 'default' with: #('Core');
			group: 'Core' with: #('Gofer-Core');
			group: 'Tests' with: #('Gofer-Tests'). ].

	spec for: #pharo do: [
		spec repository: 'http://www.squeaksource.com/Pharo'. ].

	spec for: #'pharo1.0.x' do: [
		spec repository: 'http://seaside.gemstone.com/ss/metacello'. 
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core.pharo10';
			package: 'Gofer-Tests' with: 'Gofer-Tests.pharo10'. ].

	spec for: #'pharo1.1.x' do: [
		spec repository: 'http://seaside.gemstone.com/ss/metacello'. 
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core.pharo10';
			package: 'Gofer-Tests' with: 'Gofer-Tests.pharo10'. ].

	spec for: #squeak do: [
		spec repository: 'http://seaside.gemstone.com/ss/metacello'. 
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core.squeak';
			package: 'Gofer-Tests' with: 'Gofer-Tests.squeak'. ].

	spec for: #gemstone do: [
		spec repository: 'http://seaside.gemstone.com/ss/metacello'. 
		spec package: 'Gofer-Tests' with: 'Gofer-Tests.gemstone'. ].

! !

!ConfigurationOfGofer methodsFor: 'symbolic versions' stamp: 'dkh 6/7/2011 16:45'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: #'notDefined'.
! !

!ConfigurationOfGofer methodsFor: 'accessing' stamp: 'DaleHenrichs 02/19/2010 12:41'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		self class ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear.
		"use atomic load on GemStone to resolve some loading issues"
		Smalltalk at: #SystemVersion ifAbsent: [ project loadType: #atomic ]. 
		project ]! !

!ConfigurationOfGofer methodsFor: 'symbolic versions' stamp: 'dkh 10/20/2011 14:30'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'common' version: '1.0.5'. 
	spec for: #'gemstone' version: '1.0.5.1'. 
! !

!ConfigurationOfGofer methodsFor: 'versions' stamp: 'DaleHenrichs 1/26/2010 09:58'!
version100: spec 
	<version: '1.0' imports: #('1.0-baseline') >
	
	spec for: #common do: [
		spec blessing: #release.
		spec author: 'DaleHenrichs'.
		spec timestamp: '1/25/2010 14:19'.
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-lr.116';
			package: 'Gofer-Tests' with: 'Gofer-Tests-lr.115' ].
	spec for: #pharo do: [].! !

!ConfigurationOfGofer methodsFor: 'versions' stamp: 'DaleHenrichs 2/19/2010 11:48'!
version101: spec
	<version: '1.0.1' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- use MethodReference>>methodSymbol for portability'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '02/11/10 10:22:48'.
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-DaleHenrichs.117';
			package: 'Gofer-Tests' with: 'Gofer-Tests-lr.115'.].
! !

!ConfigurationOfGofer methodsFor: 'versions' stamp: 'DaleHenrichs 6/15/2010 12:05'!
version1021: spec
	<version: '1.0.2.1' imports: #('1.0.2.1-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- add secondary repository'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '6/15/2010 10:47'.
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-dkh.121';
			package: 'Gofer-Tests' with: 'Gofer-Tests-lr.116'.].! !

!ConfigurationOfGofer methodsFor: 'versions' stamp: 'DaleHenrichs 12/13/2010 18:10'!
version1022: spec
	<version: '1.0.2.2' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '- fix a bug that prevented gofer from resolving packages in http://www.squeaksource.com/Swazoo'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '12/13/2010 16:42'.
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-DaleHenrichs.122';
			package: 'Gofer-Tests' with: 'Gofer-Tests-DaleHenrichs.117'.].
! !

!ConfigurationOfGofer methodsFor: 'versions' stamp: 'DaleHenrichs 3/23/2010 14:47'!
version102: spec
	<version: '1.0.2' imports: #('1.0-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- pick up most recent gofer code
  - updated class comments
  - another comment fix
  - added http://squeaksource.blueplane.jp/ as a well known repository
  - repository priorities were used in the wrong order (thanks to Dale Henrichs)
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '3/5/2010 09:32'.
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-dkh.121';
			package: 'Gofer-Tests' with: 'Gofer-Tests-lr.116'.].! !

!ConfigurationOfGofer methodsFor: 'versions' stamp: 'DaleHenrichs 5/14/2010 14:03'!
version103: spec
	<version: '1.0.3' imports: #('1.0-baseline' )>

	spec for: #common do: [
		spec blessing: #release.
		spec description: '- pick up most recent gofer (5/14/2010 13:54)
  - improved the method comments
  - made parser more robust
  - made tests run faster
'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '5/14/2010 14:03'.
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-StephaneDucasse.125';
			package: 'Gofer-Tests' with: 'Gofer-Tests-MarcusDenker.124'.].
	spec for: #gemstone do: [
		spec blessing: #development.
		spec description: 'not ported to GemStone, yet' ].! !

!ConfigurationOfGofer methodsFor: 'versions' stamp: 'DaleHenrichs 11/19/2010 17:37'!
version104: spec
	<version: '1.0.4' imports: #('1.0-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'match the package versions shipped in Pharo1.2a-12241'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '11/19/2010 17:26'.
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-MarcusDenker.129';
			package: 'Gofer-Tests' with: 'Gofer-Tests-StephaneDucasse.125'.].

	spec for: #'gemstone' do: [
		spec blessing: #'development'.
		spec description: 'not ported to GemStone, yet'.
].
! !

!ConfigurationOfGofer methodsFor: 'versions' stamp: 'dkh 10/20/2011 14:30'!
version1051: spec
	<version: '1.0.5.1' imports: #('1.0.5.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: '1.0.5.1 (dkh.35) [GemStone]:
- fix minor GemStone issues'.
		spec author: 'dkh'.
		spec timestamp: '10/11/2011 15:16'.
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-StephaneDucasse.133';
			package: 'Gofer-Tests' with: 'Gofer-Tests-StephaneDucasse.129'. ].

	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core.pharo10-dkh.135';
			package: 'Gofer-Tests' with: 'Gofer-Tests.pharo10-dkh.131' ].

	spec for: #'pharo1.1.x' do: [
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core.pharo10-dkh.135';
			package: 'Gofer-Tests' with: 'Gofer-Tests.pharo10-dkh.131' ].

	spec for: #'squeak' do: [
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core.squeak-dkh.135';
			package: 'Gofer-Tests' with: 'Gofer-Tests.squeak-dkh.131'. ].

	spec for: #'gemstone' do: [
		spec  
			package: 'Gofer-Core' with: 'Gofer-Core.gemstone-dkh.135';
			package: 'Gofer-Tests' with: 'Gofer-Tests.gemstone-dkh.131'. ].
! !

!ConfigurationOfGofer methodsFor: 'versions' stamp: 'dkh 6/7/2011 16:45'!
version105: spec
	<version: '1.0.5' imports: #('1.0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'release'.
		spec description: 'match Pharo1.2.1 update: #12345
- align branch naming conventions with rest of the world
  Package { "." Branch } "-" Author "." Version
- Issue 3682:	multiple undo/redo is broken in 1.2 because of Ocompletion. Part two. Thanks Alain Plantec.
-  Issue 3660:	Revert incorrect Monticello branch naming support. Thanks lukas, julian and dale.
1.0.5 (dkh.27):
- add SystemOrganizer>>environment (Squeak only)
- tweak tests to see errors plus add expectedFailure for revert ... Monticello bug in Squeak
1.0.5 (dkh.29)
- ported to GemStone ... tests green
1.0.5 (dkh.32):
- ported to Pharo1.0'.
		spec author: 'DaleHenrichs'.
		spec timestamp: '6/7/2011 15:27'.
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core-StephaneDucasse.133';
			package: 'Gofer-Tests' with: 'Gofer-Tests-StephaneDucasse.129'. ].

	spec for: #'pharo1.0.x' do: [
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core.pharo10-dkh.135';
			package: 'Gofer-Tests' with: 'Gofer-Tests.pharo10-dkh.131' ].

	spec for: #'pharo1.1.x' do: [
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core.pharo10-dkh.135';
			package: 'Gofer-Tests' with: 'Gofer-Tests.pharo10-dkh.131' ].

	spec for: #'squeak' do: [
		spec 
			package: 'Gofer-Core' with: 'Gofer-Core.squeak-dkh.135';
			package: 'Gofer-Tests' with: 'Gofer-Tests.squeak-dkh.131'. ].

	spec for: #'gemstone' do: [
		spec package: 'Gofer-Tests' with: 'Gofer-Tests.gemstone-DaleHenrichs.130'. ].
! !
